@@ -2,7 +2,7 @@
 Historical Datasets related to Earth's Moon.
 '''
 from . import gravity
-from . import topography
+from . import shape
 
 
-__all__ = ['gravity', 'topography']
+__all__ = ['gravity', 'shape']
