@@ -19,6 +19,7 @@ class SHGravGrid(object):
 
     Attributes:
 
+    name           : The name of the dataset.
     rad            : SHGrid class instance of the radial component of the
                      gravitational acceleration evaluated on an ellipsoid.
     theta          : SHGrid class instance of the theta component of the
@@ -68,7 +69,7 @@ class SHGravGrid(object):
 
     def __init__(self, rad, theta, phi, total, pot, gm, a, f, omega,
                  normal_gravity, lmax, lmax_calc, units=None, pot_units=None,
-                 epoch=None):
+                 epoch=None, name=None):
         """
         Initialize the SHGravGrid class.
         """
@@ -96,6 +97,7 @@ class SHGravGrid(object):
         self.units = units
         self.pot_units = pot_units
         self.epoch = epoch
+        self.name = name
 
     def copy(self):
         """
@@ -118,33 +120,30 @@ class SHGravGrid(object):
         print(repr(self))
 
     def __repr__(self):
-        str = ('grid = {:s}\n'
-               'nlat = {:d}\n'
-               'nlon = {:d}\n'
-               'n = {:d}\n'
-               'sampling = {:d}\n'
-               'extend = {}\n'
-               'lmax = {:d}\n'
-               'lmax_calc = {:d}\n'
-               'gm (m3 / s2) = {:e}\n'
-               'a (m)= {:e}\n'
-               'f = {:e}\n'
-               'omega (rad / s) = {:s}\n'
-               'normal gravity is removed = {:s}\n'
-               'units (gravity) = {:s}\n'
-               'units (potential) = {:s}\n'
-               'epoch = {:s}'
-               .format(self.grid, self.nlat, self.nlon, self.n, self.sampling,
-                       self.extend, self.lmax, self.lmax_calc, self.gm,
-                       self.a, self.f, repr(self.omega),
-                       repr(self.normal_gravity), repr(self.units),
-                       repr(self.pot_units), repr(self.epoch)))
-        return str
+        return (f'  name = {self.name!r}\n'
+                f'  grid = {self.grid!r}\n'
+                f'  n = {self.n}\n'
+                f'  nlat = {self.nlat}\n'
+                f'  nlon = {self.nlon}\n'
+                f'  sampling = {self.sampling}\n'
+                f'  extend = {self.extend}\n'
+                f'  lmax = {self.lmax}\n'
+                f'  lmax_calc = {self.lmax_calc}\n'
+                f'  gm (m3 / s2) = {self.gm}\n'
+                f'  a (m)= {self.a}\n'
+                f'  f = {self.f}\n'
+                f'  omega (rad / s) = {self.omega}\n'
+                f'  normal gravity is removed = {self.normal_gravity}\n'
+                f'  units (gravity) = {self.units!r}\n'
+                f'  units (potential) = {self.pot_units!r}\n'
+                f'  epoch = {self.epoch}'
+                )
 
     def plot_rad(self, projection=None, tick_interval=[30, 30],
                  minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                 title=None, titlesize=None, colorbar='right',
-                 cmap='viridis', cmap_limits=None, cmap_reverse=False,
+                 title=None, titlesize=None, title_offset=None,
+                 colorbar='right', cmap='viridis', cmap_limits=None,
+                 cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
                  cb_triangles='neither', cb_label='$g_r$, m s$^{-2}$',
                  cb_tick_interval=None, cb_offset=None,
                  cb_width=None, grid=False, axes_labelsize=None,
@@ -157,11 +156,12 @@ class SHGravGrid(object):
         Usage
         -----
         x.plot_rad([projection, tick_interval, minor_tick_interval, ticks,
-                    xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                    cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                    cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                    cb_width, grid, titlesize, axes_labelsize, tick_labelsize,
-                    ax, show, fname])
+                    xlabel, ylabel, title, title_offset, colorbar, cmap,
+                    cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                    cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                    cb_minor_tick_interval, cb_offset, cb_width, grid,
+                    titlesize, axes_labelsize, tick_labelsize, ax, show,
+                    fname])
 
         Parameters
         ----------
@@ -185,6 +185,8 @@ class SHGravGrid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -194,9 +196,14 @@ class SHGravGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -228,16 +235,19 @@ class SHGravGrid(object):
         show : bool, optional, default = True
             If True, plot the image to the screen.
         fname : str, optional, default = None
-            If present, and if axes is not specified, save the image to the
+            If present, and if ax is not specified, save the image to the
             specified file.
         """
         return self.rad.plot(projection=projection,
                              tick_interval=tick_interval,
                              minor_tick_interval=minor_tick_interval,
                              xlabel=xlabel, ylabel=ylabel, title=title,
-                             titlesize=titlesize, colorbar=colorbar,
-                             cmap=cmap, cmap_limits=cmap_limits,
-                             cmap_reverse=cmap_reverse, cb_offset=cb_offset,
+                             titlesize=titlesize, title_offset=title_offset,
+                             colorbar=colorbar, cmap=cmap,
+                             cmap_limits=cmap_limits,
+                             cmap_rlimits=cmap_rlimits,
+                             cmap_reverse=cmap_reverse, cmap_scale=cmap_scale,
+                             cb_offset=cb_offset,
                              cb_triangles=cb_triangles, cb_label=cb_label,
                              cb_tick_interval=cb_tick_interval, grid=grid,
                              axes_labelsize=axes_labelsize,
@@ -249,24 +259,26 @@ class SHGravGrid(object):
 
     def plot_theta(self, projection=None, tick_interval=[30, 30],
                    minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                   title=None, titlesize=None, colorbar='right',
-                   cmap='viridis', cmap_limits=None, cmap_reverse=False,
-                   cb_triangles='neither', cb_label='$g_\\theta$, m s$^{-2}$',
+                   title=None, titlesize=None, title_offset=None,
+                   colorbar='right', cmap='viridis', cmap_limits=None,
+                   cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
+                   cb_triangles='neither', cb_label=r'$g_\theta$, m s$^{-2}$',
                    cb_tick_interval=None, grid=False, axes_labelsize=None,
                    tick_labelsize=None, show=True, ax=None, cb_offset=None,
                    cb_minor_tick_interval=None, ticks='WSen', cb_ylabel=None,
                    fname=None, cb_width=None):
-        """
+        r"""
         Plot the theta component of the gravity field.
 
         Usage
         -----
         x.plot_theta([projection, tick_interval, minor_tick_interval, ticks,
-                      xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                      cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                      cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                      cb_width, grid, titlesize, axes_labelsize,
-                      tick_labelsize, ax, show, fname])
+                      xlabel, ylabel, title, title_offset, colorbar, cmap,
+                      cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                      cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                      cb_minor_tick_interval, cb_offset, cb_width, grid,
+                      titlesize, axes_labelsize, tick_labelsize, ax, show,
+                      fname])
 
         Parameters
         ----------
@@ -290,6 +302,8 @@ class SHGravGrid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -299,13 +313,18 @@ class SHGravGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
-        cb_label : str, optional, default = '$g_r$, m s$^{-2}$'
+        cb_label : str, optional, default = r'$g_\theta$, m s$^{-2}$'
             Text label for the colorbar.
         cb_ylabel : str, optional, default = None
             Text label for the y axis of the colorbar
@@ -333,15 +352,18 @@ class SHGravGrid(object):
         show : bool, optional, default = True
             If True, plot the image to the screen.
         fname : str, optional, default = None
-            If present, and if axes is not specified, save the image to the
+            If present, and if ax is not specified, save the image to the
             specified file.
         """
         return self.theta.plot(projection=projection,
                                tick_interval=tick_interval,
                                minor_tick_interval=minor_tick_interval,
                                xlabel=xlabel, ylabel=ylabel, title=title,
-                               titlesize=titlesize, colorbar=colorbar,
-                               cmap=cmap, cmap_limits=cmap_limits,
+                               titlesize=titlesize, title_offset=title_offset,
+                               colorbar=colorbar, cmap=cmap,
+                               cmap_limits=cmap_limits,
+                               cmap_rlimits=cmap_rlimits,
+                               cmap_scale=cmap_scale,
                                cmap_reverse=cmap_reverse, cb_offset=cb_offset,
                                cb_triangles=cb_triangles, cb_label=cb_label,
                                cb_tick_interval=cb_tick_interval, grid=grid,
@@ -354,24 +376,26 @@ class SHGravGrid(object):
 
     def plot_phi(self, projection=None, tick_interval=[30, 30],
                  minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                 title=None, titlesize=None, colorbar='right',
-                 cmap='viridis', cmap_limits=None, cmap_reverse=False,
-                 cb_triangles='neither', cb_label='$g_\phi$, m s$^{-2}$',
+                 title=None, titlesize=None, title_offset=None,
+                 colorbar='right', cmap='viridis', cmap_limits=None,
+                 cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
+                 cb_triangles='neither', cb_label=r'$g_\phi$, m s$^{-2}$',
                  cb_tick_interval=None, grid=False, axes_labelsize=None,
                  tick_labelsize=None, show=True, ax=None, cb_offset=None,
                  cb_minor_tick_interval=None, ticks='WSen', cb_ylabel=None,
                  cb_width=None, fname=None):
-        """
+        r"""
         Plot the phi component of the gravity field.
 
         Usage
         -----
         x.plot_phi([projection, tick_interval, minor_tick_interval, ticks,
-                    xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                    cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                    cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                    cb_width, grid, titlesize, axes_labelsize, tick_labelsize,
-                    ax, show, fname])
+                    xlabel, ylabel, title, title_offset, colorbar, cmap,
+                    cmap_limits, cmap_reverse, cmap_scale, cb_triangles,
+                    cb_label, cb_ylabel, cb_tick_interval,
+                    cb_minor_tick_interval, cb_offset, cb_width, grid,
+                    titlesize, axes_labelsize, tick_labelsize, ax, show,
+                    fname])
 
         Parameters
         ----------
@@ -395,6 +419,8 @@ class SHGravGrid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -404,13 +430,18 @@ class SHGravGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
-        cb_label : str, optional, default = '$g_\phi$, m s$^{-2}$'
+        cb_label : str, optional, default = r'$g_\phi$, m s$^{-2}$'
             Text label for the colorbar.
         cb_ylabel : str, optional, default = None
             Text label for the y axis of the colorbar
@@ -438,15 +469,17 @@ class SHGravGrid(object):
         show : bool, optional, default = True
             If True, plot the image to the screen.
         fname : str, optional, default = None
-            If present, and if axes is not specified, save the image to the
+            If present, and if ax is not specified, save the image to the
             specified file.
         """
         return self.phi.plot(projection=projection,
                              tick_interval=tick_interval,
                              minor_tick_interval=minor_tick_interval,
                              xlabel=xlabel, ylabel=ylabel, title=title,
-                             titlesize=titlesize, colorbar=colorbar,
-                             cmap=cmap, cmap_limits=cmap_limits,
+                             titlesize=titlesize, title_offset=title_offset,
+                             colorbar=colorbar, cmap=cmap,
+                             cmap_limits=cmap_limits,
+                             cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                              cmap_reverse=cmap_reverse, cb_offset=cb_offset,
                              cb_triangles=cb_triangles, cb_label=cb_label,
                              cb_tick_interval=cb_tick_interval, grid=grid,
@@ -459,8 +492,9 @@ class SHGravGrid(object):
 
     def plot_total(self, projection=None, tick_interval=[30, 30],
                    minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                   title=None, titlesize=None, colorbar='right',
-                   cmap='viridis', cmap_limits=None, cmap_reverse=False,
+                   title=None, titlesize=None, title_offset=None,
+                   colorbar='right', cmap='viridis', cmap_limits=None,
+                   cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
                    cb_triangles='neither', cb_label='Gravity disturbance',
                    cb_tick_interval=None, grid=False, axes_labelsize=None,
                    tick_labelsize=None, show=True, ax=None, cb_offset=None,
@@ -472,11 +506,12 @@ class SHGravGrid(object):
         Usage
         -----
         x.plot_total([projection, tick_interval, minor_tick_interval, ticks,
-                      xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                      cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                      cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                      cb_width, grid, titlesize, axes_labelsize,
-                      tick_labelsize, ax, show, fname])
+                      xlabel, ylabel, title, title_offset, colorbar, cmap,
+                      cmap_limits, cmap_rlimits, cmap_scale, cmap_reverse,
+                      cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                      cb_minor_tick_interval, cb_offset, cb_width, grid,
+                      titlesize, axes_labelsize, tick_labelsize, ax, show,
+                      fname])
 
         Parameters
         ----------
@@ -500,6 +535,8 @@ class SHGravGrid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -509,9 +546,14 @@ class SHGravGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -543,7 +585,7 @@ class SHGravGrid(object):
         show : bool, optional, default = True
             If True, plot the image to the screen.
         fname : str, optional, default = None
-            If present, and if axes is not specified, save the image to the
+            If present, and if ax is not specified, save the image to the
             specified file.
 
         Note
@@ -567,22 +609,23 @@ class SHGravGrid(object):
                          tick_interval=tick_interval,
                          minor_tick_interval=minor_tick_interval,
                          xlabel=xlabel, ylabel=ylabel, title=title,
-                         titlesize=titlesize, colorbar=colorbar,
-                         cmap=cmap, cmap_limits=cmap_limits,
+                         titlesize=titlesize, title_offset=title_offset,
+                         colorbar=colorbar, cmap=cmap, cmap_limits=cmap_limits,
+                         cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                          cmap_reverse=cmap_reverse, cb_offset=cb_offset,
                          cb_triangles=cb_triangles, cb_label=cb_label,
                          cb_tick_interval=cb_tick_interval, grid=grid,
-                         axes_labelsize=axes_labelsize,
-                         cb_ylabel=cb_ylabel, ticks=ticks,
-                         cb_width=cb_width,
+                         axes_labelsize=axes_labelsize,  cb_ylabel=cb_ylabel,
+                         ticks=ticks, cb_width=cb_width,
                          cb_minor_tick_interval=cb_minor_tick_interval,
-                         tick_labelsize=tick_labelsize, ax=ax,
-                         show=show, fname=fname)
+                         tick_labelsize=tick_labelsize, ax=ax, show=show,
+                         fname=fname)
 
     def plot_pot(self, projection=None, tick_interval=[30, 30],
                  minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                 title=None, titlesize=None, colorbar='right',
-                 cmap='viridis', cmap_limits=None, cmap_reverse=False,
+                 title=None, titlesize=None, title_offset=None,
+                 colorbar='right', cmap='viridis', cmap_limits=None,
+                 cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
                  cb_triangles='neither', cb_label='Potential, m$^2$ s$^{-2}$',
                  cb_tick_interval=None, grid=False, axes_labelsize=None,
                  tick_labelsize=None, show=True, ax=None, cb_offset=None,
@@ -594,11 +637,12 @@ class SHGravGrid(object):
         Usage
         -----
         x.plot_pot([projection, tick_interval, minor_tick_interval, ticks,
-                    xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                    cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                    cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                    cb_width, grid, titlesize, axes_labelsize, tick_labelsize,
-                    ax, show, fname])
+                    xlabel, ylabel, title, title_offset, colorbar, cmap,
+                    cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                    cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                    cb_minor_tick_interval, cb_offset, cb_width, grid,
+                    titlesize, axes_labelsize, tick_labelsize, ax, show,
+                    fname])
 
         Parameters
         ----------
@@ -622,6 +666,8 @@ class SHGravGrid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -631,9 +677,14 @@ class SHGravGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -665,15 +716,17 @@ class SHGravGrid(object):
         show : bool, optional, default = True
             If True, plot the image to the screen.
         fname : str, optional, default = None
-            If present, and if axes is not specified, save the image to the
+            If present, and if ax is not specified, save the image to the
             specified file.
         """
         return self.pot.plot(projection=projection,
                              tick_interval=tick_interval,
                              minor_tick_interval=minor_tick_interval,
                              xlabel=xlabel, ylabel=ylabel, title=title,
-                             titlesize=titlesize, colorbar=colorbar,
-                             cmap=cmap, cmap_limits=cmap_limits,
+                             titlesize=titlesize, title_offset=title_offset,
+                             colorbar=colorbar, cmap=cmap,
+                             cmap_limits=cmap_limits,
+                             cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                              cmap_reverse=cmap_reverse, cb_offset=cb_offset,
                              cb_triangles=cb_triangles, cb_label=cb_label,
                              cb_tick_interval=cb_tick_interval, grid=grid,
@@ -686,10 +739,11 @@ class SHGravGrid(object):
 
     def plot(self, projection=None, tick_interval=[60, 30],
              minor_tick_interval=[None, None], xlabel='Longitude',
-             ylabel='Latitude', colorbar='bottom', cmap='viridis',
-             cmap_limits=None, cmap_reverse=False, cb_triangles='neither',
-             cb_tick_interval=None, grid=False, axes_labelsize=9,
-             tick_labelsize=8, show=True, cb_offset=None,
+             ylabel='Latitude', title_offset=None, colorbar='bottom',
+             cmap='viridis', cmap_limits=None, cmap_rlimits=None,
+             cmap_reverse=False, cmap_scale='lin', cb_triangles='neither',
+             cb_tick_interval=None, grid=False, titlesize=None,
+             axes_labelsize=9, tick_labelsize=8, show=True, cb_offset=None,
              cb_minor_tick_interval=None, ticks='WSen', cb_ylabel=None,
              cb_width=None, fname=None):
         """
@@ -698,11 +752,12 @@ class SHGravGrid(object):
 
         Usage
         -----
-        x.plot([projection, tick_interval, minor_tick_interval, ticks, xlabel,
-                ylabel, colorbar, cmap, cmap_limits, cmap_reverse,
-                cb_triangles, cb_ylabel, cb_tick_interval,
-                cb_minor_tick_interval, cb_offset, cb_width, grid,
-                axes_labelsize, tick_labelsize, show, fname])
+        x.plot([projection, tick_interval, minor_tick_interval, ticks,
+                title_offset, xlabel, ylabel, colorbar, cmap, cmap_limits,
+                cmap_rlimits, cmap_reverse, cmap_scale, cb_triangles,
+                cb_ylabel, cb_tick_interval, cb_minor_tick_interval,
+                cb_offset, cb_width, grid, titlesize, axes_labelsize,
+                tick_labelsize, show, fname])
 
         Parameters
         ----------
@@ -720,6 +775,8 @@ class SHGravGrid(object):
             letters plot the ticks and annotations, whereas small letters plot
             only the ticks. 'W', 'S', 'E', and 'N' denote the west, south, east
             and north boundaries of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         xlabel : str, optional, default = 'longitude'
             Label for the longitude axis.
         ylabel : str, optional, default = 'latitude'
@@ -733,9 +790,14 @@ class SHGravGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -754,6 +816,8 @@ class SHGravGrid(object):
             horizontal colorbars, respectively.
         grid : bool, optional, default = False
             If True, plot major grid lines.
+        titlesize : int, optional, default = None
+            The font size of the title.
         axes_labelsize : int, optional, default = None
             The font size for the x and y axes labels.
         tick_labelsize : int, optional, default = None
@@ -761,7 +825,7 @@ class SHGravGrid(object):
         show : bool, optional, default = True
             If True, plot the image to the screen.
         fname : str, optional, default = None
-            If present, and if axes is not specified, save the image to the
+            If present, and if ax is not specified, save the image to the
             specified file.
         """
         if colorbar is not None:
@@ -779,8 +843,9 @@ class SHGravGrid(object):
                       tick_interval=tick_interval,
                       minor_tick_interval=minor_tick_interval,
                       xlabel=xlabel, ylabel=ylabel, title=None,
-                      titlesize=None, colorbar=colorbar,
-                      cmap=cmap, cmap_limits=cmap_limits,
+                      title_offset=title_offset, titlesize=titlesize,
+                      colorbar=colorbar, cmap=cmap, cmap_limits=cmap_limits,
+                      cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                       cmap_reverse=cmap_reverse, cb_triangles=cb_triangles,
                       cb_tick_interval=cb_tick_interval,
                       grid=grid, axes_labelsize=axes_labelsize,
@@ -792,8 +857,9 @@ class SHGravGrid(object):
                         tick_interval=tick_interval,
                         minor_tick_interval=minor_tick_interval,
                         xlabel=xlabel, ylabel=ylabel, title=None,
-                        titlesize=None, colorbar=colorbar,
-                        cmap=cmap, cmap_limits=cmap_limits,
+                        titlesize=titlesize, title_offset=title_offset,
+                        colorbar=colorbar, cmap=cmap, cmap_limits=cmap_limits,
+                        cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                         cmap_reverse=cmap_reverse, cb_triangles=cb_triangles,
                         cb_tick_interval=cb_tick_interval,
                         grid=grid, axes_labelsize=axes_labelsize,
@@ -805,8 +871,9 @@ class SHGravGrid(object):
                       tick_interval=tick_interval,
                       minor_tick_interval=minor_tick_interval,
                       xlabel=xlabel, ylabel=ylabel, title=None,
-                      titlesize=None, colorbar=colorbar,
-                      cmap=cmap, cmap_limits=cmap_limits,
+                      titlesize=titlesize, title_offset=title_offset,
+                      colorbar=colorbar, cmap=cmap, cmap_limits=cmap_limits,
+                      cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                       cmap_reverse=cmap_reverse, cb_triangles=cb_triangles,
                       cb_tick_interval=cb_tick_interval,
                       grid=grid, axes_labelsize=axes_labelsize,
@@ -818,8 +885,9 @@ class SHGravGrid(object):
                         tick_interval=tick_interval,
                         minor_tick_interval=minor_tick_interval,
                         xlabel=xlabel, ylabel=ylabel, title=None,
-                        titlesize=None, colorbar=colorbar,
-                        cmap=cmap, cmap_limits=cmap_limits,
+                        titlesize=titlesize, title_offset=title_offset,
+                        colorbar=colorbar, cmap=cmap, cmap_limits=cmap_limits,
+                        cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                         cmap_reverse=cmap_reverse, cb_triangles=cb_triangles,
                         cb_tick_interval=cb_tick_interval,
                         grid=grid, axes_labelsize=axes_labelsize,
@@ -876,10 +944,10 @@ class SHGravGrid(object):
         _rad = self.rad.to_xarray(title='gravity (radial)',
                                   long_name='$g_r$', units='$m s^{-2}$')
         _theta = self.theta.to_xarray(title='gravity (theta)',
-                                      long_name='$g_\\theta$',
+                                      long_name=r'$g_\theta$',
                                       units='$m s^{-2}$')
         _phi = self.phi.to_xarray(title='gravity (phi)',
-                                  long_name='$g_\\phi$', units='$m s^{-2}$')
+                                  long_name=r'$g_\phi$', units='$m s^{-2}$')
         _pot = self.pot.to_xarray(title='gravitational potential',
                                   long_name='potential', units='$m^2 s^{-2}$')
 
