@@ -19,6 +19,7 @@ class SHMagGrid(object):
 
     Attributes:
 
+    name           : The name of the dataset.
     rad            : SHGrid class instance of the radial component of the
                      magnetic field evaluated on an ellipsoid.
     theta          : SHGrid class instance of the theta component of the
@@ -62,7 +63,7 @@ class SHMagGrid(object):
     """
 
     def __init__(self, rad, theta, phi, total, pot, a, f, lmax, lmax_calc,
-                 units=None, pot_units=None, year=None):
+                 units=None, pot_units=None, year=None, name=None):
         """
         Initialize the SHMagGrid class.
         """
@@ -84,6 +85,7 @@ class SHMagGrid(object):
         self.units = units
         self.pot_units = pot_units
         self.year = year
+        self.name = name
 
     def copy(self):
         """
@@ -106,29 +108,27 @@ class SHMagGrid(object):
         print(repr(self))
 
     def __repr__(self):
-        str = ('grid = {:s}\n'
-               'nlat = {:d}\n'
-               'nlon = {:d}\n'
-               'n = {:d}\n'
-               'sampling = {:d}\n'
-               'extend = {}\n'
-               'lmax = {:d}\n'
-               'lmax_calc = {:d}\n'
-               'a (m)= {:e}\n'
-               'f = {:e}\n'
-               'units (magnetic field) = {:s}\n'
-               'units (potential) = {:s}\n'
-               'year = {:s}'
-               .format(self.grid, self.nlat, self.nlon, self.n, self.sampling,
-                       self.extend, self.lmax, self.lmax_calc, self.a,
-                       self.f, repr(self.units), repr(self.pot_units),
-                       repr(self.year)))
-        return str
+        return (f'  name = {self.name!r}\n'
+                f'  grid = {self.grid!r}\n'
+                f'  n = {self.n}\n'
+                f'  nlat = {self.nlat}\n'
+                f'  nlon = {self.nlon}\n'
+                f'  sampling = {self.sampling}\n'
+                f'  extend = {self.extend}\n'
+                f'  lmax = {self.lmax}\n'
+                f'  lmax_calc = {self.lmax_calc}\n'
+                f'  a (m) = {self.a}\n'
+                f'  f = {self.f}\n'
+                f'  units (magnetic field) = {self.units!r}\n'
+                f'  units (potential) = {self.pot_units!r}\n'
+                f'  year = {self.year}'
+                )
 
     def plot_rad(self, projection=None, tick_interval=[30, 30],
                  minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                 title=None, titlesize=None, colorbar='right',
-                 cmap='viridis', cmap_limits=None, cmap_reverse=False,
+                 title=None, titlesize=None, title_offset=None,
+                 colorbar='right', cmap='viridis', cmap_limits=None,
+                 cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
                  cb_triangles='neither', cb_label='$B_r$, nT',
                  cb_tick_interval=None, grid=False, axes_labelsize=None,
                  tick_labelsize=None, show=True, ax=None, cb_offset=None,
@@ -140,11 +140,12 @@ class SHMagGrid(object):
         Usage
         -----
         x.plot_rad([projection, tick_interval, minor_tick_interval, ticks,
-                    xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                    cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                    cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                    cb_width, grid, titlesize, axes_labelsize, tick_labelsize,
-                    ax, show, fname])
+                    xlabel, ylabel, title, title_offset, colorbar, cmap,
+                    cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                    cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                    cb_minor_tick_interval, cb_offset, cb_width, grid,
+                    titlesize, axes_labelsize, tick_labelsize, ax, show,
+                    fname])
 
         Parameters
         ----------
@@ -168,6 +169,8 @@ class SHMagGrid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -177,9 +180,14 @@ class SHMagGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -221,8 +229,10 @@ class SHMagGrid(object):
                              tick_interval=tick_interval,
                              minor_tick_interval=minor_tick_interval,
                              xlabel=xlabel, ylabel=ylabel, title=title,
-                             titlesize=titlesize, colorbar=colorbar,
-                             cmap=cmap, cmap_limits=cmap_limits,
+                             titlesize=titlesize, title_offset=title_offset,
+                             colorbar=colorbar, cmap=cmap,
+                             cmap_limits=cmap_limits,
+                             cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                              cmap_reverse=cmap_reverse, cb_offset=cb_offset,
                              cb_triangles=cb_triangles, cb_label=cb_label,
                              cb_tick_interval=cb_tick_interval, grid=grid,
@@ -235,8 +245,9 @@ class SHMagGrid(object):
 
     def plot_theta(self, projection=None, tick_interval=[30, 30],
                    minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                   title=None, titlesize=None, colorbar='right',
-                   cmap='viridis', cmap_limits=None, cmap_reverse=False,
+                   title=None, titlesize=None, title_offset=None,
+                   colorbar='right', cmap='viridis', cmap_limits=None,
+                   cmap_rlimits=None, cmap_scale='lin', cmap_reverse=False,
                    cb_triangles='neither', cb_label=r'$B_\theta$, nT',
                    cb_tick_interval=None, grid=False, axes_labelsize=None,
                    tick_labelsize=None, show=True, ax=None, cb_offset=None,
@@ -248,11 +259,12 @@ class SHMagGrid(object):
         Usage
         -----
         x.plot_theta([projection, tick_interval, minor_tick_interval, ticks,
-                      xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                      cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                      cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                      cb_width, grid, titlesize, axes_labelsize,
-                      tick_labelsize, ax, show, fname])
+                      xlabel, ylabel, title, title_offset, colorbar, cmap,
+                      cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                      cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                      cb_minor_tick_interval, cb_offset, cb_width, grid,
+                      titlesize, axes_labelsize, tick_labelsize, ax, show,
+                      fname])
 
         Parameters
         ----------
@@ -276,6 +288,8 @@ class SHMagGrid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -285,9 +299,14 @@ class SHMagGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -329,8 +348,10 @@ class SHMagGrid(object):
                                tick_interval=tick_interval,
                                minor_tick_interval=minor_tick_interval,
                                xlabel=xlabel, ylabel=ylabel, title=title,
-                               titlesize=titlesize, colorbar=colorbar,
-                               cmap=cmap, cmap_limits=cmap_limits,
+                               titlesize=titlesize, title_offset=title_offset,
+                               colorbar=colorbar, cmap=cmap,
+                               cmap_limits=cmap_limits, cmap_scale=cmap_scale,
+                               cmap_rlimits=cmap_rlimits,
                                cmap_reverse=cmap_reverse, cb_offset=cb_offset,
                                cb_triangles=cb_triangles, cb_label=cb_label,
                                cb_tick_interval=cb_tick_interval, grid=grid,
@@ -343,8 +364,9 @@ class SHMagGrid(object):
 
     def plot_phi(self, projection=None, tick_interval=[30, 30],
                  minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                 title=None, titlesize=None, colorbar='right',
-                 cmap='viridis', cmap_limits=None, cmap_reverse=False,
+                 title=None, titlesize=None, title_offset=None,
+                 colorbar='right', cmap='viridis', cmap_limits=None,
+                 cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
                  cb_triangles='neither', cb_label=r'$B_\phi$, nT',
                  cb_tick_interval=None, grid=False, axes_labelsize=None,
                  tick_labelsize=None, show=True, ax=None, cb_offset=None,
@@ -356,11 +378,12 @@ class SHMagGrid(object):
         Usage
         -----
         x.plot_phi([projection, tick_interval, minor_tick_interval, ticks,
-                    xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                    cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                    cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                    cb_width, grid, titlesize, axes_labelsize, tick_labelsize,
-                    ax, show, fname])
+                    xlabel, ylabel, title, title_offset, colorbar, cmap,
+                    cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                    cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                    cb_minor_tick_interval, cb_offset, cb_width, grid,
+                    titlesize, axes_labelsize, tick_labelsize, ax, show,
+                    fname])
 
         Parameters
         ----------
@@ -384,6 +407,8 @@ class SHMagGrid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -393,9 +418,14 @@ class SHMagGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -437,8 +467,10 @@ class SHMagGrid(object):
                              tick_interval=tick_interval,
                              minor_tick_interval=minor_tick_interval,
                              xlabel=xlabel, ylabel=ylabel, title=title,
-                             titlesize=titlesize, colorbar=colorbar,
-                             cmap=cmap, cmap_limits=cmap_limits,
+                             titlesize=titlesize, title_offset=title_offset,
+                             colorbar=colorbar, cmap=cmap,
+                             cmap_limits=cmap_limits, cmap_scale=cmap_scale,
+                             cmap_rlimits=cmap_rlimits,
                              cmap_reverse=cmap_reverse, cb_offset=cb_offset,
                              cb_triangles=cb_triangles, cb_label=cb_label,
                              cb_tick_interval=cb_tick_interval, grid=grid,
@@ -451,8 +483,9 @@ class SHMagGrid(object):
 
     def plot_total(self, projection=None, tick_interval=[30, 30],
                    minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                   title=None, titlesize=None, colorbar='right',
-                   cmap='viridis', cmap_limits=None, cmap_reverse=False,
+                   title=None, titlesize=None, title_offset=None,
+                   colorbar='right', cmap='viridis', cmap_limits=None,
+                   cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
                    cb_triangles='neither', cb_label='$|B|$, nT',
                    cb_tick_interval=None, grid=False, axes_labelsize=None,
                    tick_labelsize=None, show=True, ax=None, cb_offset=None,
@@ -464,11 +497,12 @@ class SHMagGrid(object):
         Usage
         -----
         x.plot_total([projection, tick_interval, minor_tick_interval, ticks,
-                      xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                      cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                      cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                      cb_width, grid, titlesize, axes_labelsize,
-                      tick_labelsize, ax, show, fname])
+                      xlabel, ylabel, title, title_offset, colorbar, cmap,
+                      cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                      cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                      cb_minor_tick_interval, cb_offset, cb_width, grid,
+                      titlesize, axes_labelsize, tick_labelsize, ax, show,
+                      fname])
 
         Parameters
         ----------
@@ -492,6 +526,8 @@ class SHMagGrid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -501,9 +537,14 @@ class SHMagGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -545,8 +586,10 @@ class SHMagGrid(object):
                                tick_interval=tick_interval,
                                minor_tick_interval=minor_tick_interval,
                                xlabel=xlabel, ylabel=ylabel, title=title,
-                               titlesize=titlesize, colorbar=colorbar,
-                               cmap=cmap, cmap_limits=cmap_limits,
+                               titlesize=titlesize, title_offset=title_offset,
+                               colorbar=colorbar, cmap=cmap,
+                               cmap_limits=cmap_limits, cmap_scale=cmap_scale,
+                               cmap_rlimits=cmap_rlimits,
                                cmap_reverse=cmap_reverse, cb_offset=cb_offset,
                                cb_triangles=cb_triangles, cb_label=cb_label,
                                cb_tick_interval=cb_tick_interval, grid=grid,
@@ -559,8 +602,9 @@ class SHMagGrid(object):
 
     def plot_pot(self, projection=None, tick_interval=[30, 30],
                  minor_tick_interval=[None, None], xlabel=None, ylabel=None,
-                 title=None, titlesize=None, colorbar='right',
-                 cmap='viridis', cmap_limits=None, cmap_reverse=False,
+                 title=None, titlesize=None, title_offset=None,
+                 colorbar='right', cmap='viridis', cmap_limits=None,
+                 cmap_rlimits=None, cmap_reverse=False, cmap_scale='lin',
                  cb_triangles='neither', cb_label='Potential, nT m',
                  cb_tick_interval=None, grid=False, axes_labelsize=None,
                  tick_labelsize=None, show=True, ax=None, cb_offset=None,
@@ -572,11 +616,12 @@ class SHMagGrid(object):
         Usage
         -----
         x.plot_pot([projection, tick_interval, minor_tick_interval, ticks,
-                    xlabel, ylabel, title, colorbar, cmap, cmap_limits,
-                    cmap_reverse, cb_triangles, cb_label, cb_ylabel,
-                    cb_tick_interval, cb_minor_tick_interval, cb_offset,
-                    cb_width, grid, titlesize, axes_labelsize, tick_labelsize,
-                    ax, show, fname])
+                    xlabel, ylabel, title, title_offset, colorbar, cmap,
+                    cmap_limits, cmap_rlimits, cmap_reverse, cmap_scale,
+                    cb_triangles, cb_label, cb_ylabel, cb_tick_interval,
+                    cb_minor_tick_interval, cb_offset, cb_width, grid,
+                    titlesize, axes_labelsize, tick_labelsize, ax, show,
+                    fname])
 
         Parameters
         ----------
@@ -600,6 +645,8 @@ class SHMagGrid(object):
             Label for the latitude axis.
         title : str or list, optional, default = None
             The title of the plot.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'right'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -609,9 +656,14 @@ class SHMagGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -653,8 +705,10 @@ class SHMagGrid(object):
                              tick_interval=tick_interval,
                              minor_tick_interval=minor_tick_interval,
                              xlabel=xlabel, ylabel=ylabel, title=title,
-                             titlesize=titlesize, colorbar=colorbar,
-                             cmap=cmap, cmap_limits=cmap_limits,
+                             titlesize=titlesize, title_offset=title_offset,
+                             colorbar=colorbar, cmap=cmap,
+                             cmap_limits=cmap_limits, cmap_scale=cmap_scale,
+                             cmap_rlimits=cmap_rlimits,
                              cmap_reverse=cmap_reverse, cb_offset=cb_offset,
                              cb_triangles=cb_triangles, cb_label=cb_label,
                              cb_tick_interval=cb_tick_interval, grid=grid,
@@ -667,10 +721,11 @@ class SHMagGrid(object):
 
     def plot(self, projection=None, tick_interval=[60, 30],
              minor_tick_interval=[None, None], xlabel='Longitude',
-             ylabel='Latitude', colorbar='bottom', cmap='viridis',
-             cmap_limits=None, cmap_reverse=False, cb_triangles='neither',
-             cb_tick_interval=None, grid=False, axes_labelsize=9,
-             tick_labelsize=8, show=True, cb_offset=None,
+             ylabel='Latitude', colorbar='bottom', title_offset=None,
+             cmap='viridis', cmap_limits=None, cmap_rlimits=None,
+             cmap_reverse=False, cmap_scale='lin', cb_triangles='neither',
+             cb_tick_interval=None, grid=False, titlesize=None,
+             axes_labelsize=9, tick_labelsize=8, show=True, cb_offset=None,
              cb_minor_tick_interval=None, ticks='WSen', cb_ylabel=None,
              cb_width=None, fname=None):
         """
@@ -682,7 +737,7 @@ class SHMagGrid(object):
         x.plot([projection, tick_interval, minor_tick_interval, ticks, xlabel,
                 ylabel, colorbar, cmap, cmap_limits, cmap_reverse,
                 cb_triangles, cb_ylabel, cb_tick_interval,
-                cb_minor_tick_interval, cb_offset, cb_width, grid,
+                cb_minor_tick_interval, cb_offset, cb_width, grid, titlesize,
                 axes_labelsize, tick_labelsize, show, fname])
 
         Parameters
@@ -705,6 +760,8 @@ class SHMagGrid(object):
             Label for the longitude axis.
         ylabel : str, optional, default = 'latitude'
             Label for the latitude axis.
+        title_offset : float, optional, default = None
+            The offset between the title and top of the plot in points.
         colorbar : str, optional, default = 'bottom'
             Plot a colorbar along the 'top', 'right', 'bottom', or 'left' axis.
         cmap : str, optional, default = 'viridis'
@@ -714,9 +771,14 @@ class SHMagGrid(object):
             and optionally an interval for each color band. If the interval is
             specified, the number of discrete colors will be
             (cmap_limits[1]-cmap_limits[0])/cmap_limits[2].
+        cmap_rlimits : list, optional, default = None
+           Same as cmap_limits, except the provided upper and lower values are
+           relative with respect to the maximum value of the data.
         cmap_reverse : bool, optional, default = False
             Set to True to reverse the sense of the color progression in the
             color table.
+        cmap_scale : str, optional, default = 'lin'
+            Scale of the color axis: 'lin' for linear or 'log' for logarithmic.
         cb_triangles : str, optional, default = 'neither'
             Add triangles to the edges of the colorbar for minimum and maximum
             values. Can be 'neither', 'both', 'min', or 'max'.
@@ -735,6 +797,8 @@ class SHMagGrid(object):
             horizontal colorbars, respectively.
         grid : bool, optional, default = False
             If True, plot major grid lines.
+        titlesize : int, optional, default = None
+            The font size of the title.
         axes_labelsize : int, optional, default = None
             The font size for the x and y axes labels.
         tick_labelsize : int, optional, default = None
@@ -760,8 +824,9 @@ class SHMagGrid(object):
                       tick_interval=tick_interval,
                       minor_tick_interval=minor_tick_interval,
                       xlabel=xlabel, ylabel=ylabel, title=None,
-                      titlesize=None, colorbar=colorbar,
-                      cmap=cmap, cmap_limits=cmap_limits,
+                      titlesize=titlesize, title_offset=title_offset,
+                      colorbar=colorbar, cmap=cmap, cmap_limits=cmap_limits,
+                      cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                       cmap_reverse=cmap_reverse, cb_triangles=cb_triangles,
                       cb_tick_interval=cb_tick_interval,
                       grid=grid, axes_labelsize=axes_labelsize,
@@ -774,8 +839,9 @@ class SHMagGrid(object):
                         tick_interval=tick_interval,
                         minor_tick_interval=minor_tick_interval,
                         xlabel=xlabel, ylabel=ylabel, title=None,
-                        titlesize=None, colorbar=colorbar,
-                        cmap=cmap, cmap_limits=cmap_limits,
+                        title_offset=title_offset, titlesize=titlesize,
+                        colorbar=colorbar, cmap=cmap, cmap_limits=cmap_limits,
+                        cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                         cmap_reverse=cmap_reverse, cb_triangles=cb_triangles,
                         cb_tick_interval=cb_tick_interval,
                         grid=grid, axes_labelsize=axes_labelsize,
@@ -788,8 +854,9 @@ class SHMagGrid(object):
                       tick_interval=tick_interval,
                       minor_tick_interval=minor_tick_interval,
                       xlabel=xlabel, ylabel=ylabel, title=None,
-                      titlesize=None, colorbar=colorbar,
-                      cmap=cmap, cmap_limits=cmap_limits,
+                      title_offset=title_offset, titlesize=titlesize,
+                      colorbar=colorbar, cmap=cmap, cmap_limits=cmap_limits,
+                      cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                       cmap_reverse=cmap_reverse, cb_triangles=cb_triangles,
                       cb_tick_interval=cb_tick_interval,
                       grid=grid, axes_labelsize=axes_labelsize,
@@ -802,8 +869,9 @@ class SHMagGrid(object):
                         tick_interval=tick_interval,
                         minor_tick_interval=minor_tick_interval,
                         xlabel=xlabel, ylabel=ylabel, title=None,
-                        titlesize=None, colorbar=colorbar,
-                        cmap=cmap, cmap_limits=cmap_limits,
+                        title_offset=title_offset, titlesize=titlesize,
+                        colorbar=colorbar, cmap=cmap, cmap_limits=cmap_limits,
+                        cmap_rlimits=cmap_rlimits, cmap_scale=cmap_scale,
                         cmap_reverse=cmap_reverse, cb_triangles=cb_triangles,
                         cb_tick_interval=cb_tick_interval,
                         grid=grid, axes_labelsize=axes_labelsize,
